@@ -29,8 +29,6 @@ from osc_lib.utils import tags as _tag
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
 from openstackclient.network import common
-from openstackclient.network import sdk_utils
-
 
 LOG = logging.getLogger(__name__)
 
@@ -67,7 +65,7 @@ def _get_columns(item):
         'is_port_security_enabled': 'port_security_enabled',
         'tenant_id': 'project_id',
     }
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(item, column_map)
+    return utils.get_osc_show_columns_for_sdk_resource(item, column_map)
 
 
 class JSONKeyValueAction(argparse.Action):
@@ -255,11 +253,15 @@ def _add_updatable_args(parser):
     parser.add_argument(
         '--vnic-type',
         metavar='<vnic-type>',
-        choices=['direct', 'direct-physical', 'macvtap',
-                 'normal', 'baremetal', 'virtio-forwarder'],
-        help=_("VNIC type for this port (direct | direct-physical | "
-               "macvtap | normal | baremetal | virtio-forwarder, "
-               "default: normal)")
+        choices=(
+            'direct', 'direct-physical', 'macvtap',
+            'normal', 'baremetal', 'virtio-forwarder', 'vdpa'
+        ),
+        help=_(
+            "VNIC type for this port (direct | direct-physical | "
+            "macvtap | normal | baremetal | virtio-forwarder | vdpa, "
+            "default: normal)"
+        ),
     )
     parser.add_argument(
         '--host',
@@ -322,7 +324,7 @@ def _convert_extra_dhcp_options(parsed_args):
     return dhcp_options
 
 
-class CreatePort(command.ShowOne):
+class CreatePort(command.ShowOne, common.NeutronCommandWithExtraArgs):
     _description = _("Create a new port")
 
     def get_parser(self, prog_name):
@@ -497,6 +499,9 @@ class CreatePort(command.ShowOne):
             if parsed_args.tags:
                 attrs['tags'] = list(set(parsed_args.tags))
 
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
+
         with common.check_missing_extension_if_error(
                 self.app.client_manager.network, attrs):
             obj = client.create_port(**attrs)
@@ -693,7 +698,7 @@ class ListPort(command.Lister):
 
 # TODO(abhiraut): Use the SDK resource mapped attribute names once the
 # OSC minimum requirements include SDK 1.0.
-class SetPort(command.Command):
+class SetPort(common.NeutronCommandWithExtraArgs):
     _description = _("Set port properties")
 
     def get_parser(self, prog_name):
@@ -867,6 +872,9 @@ class SetPort(command.Command):
         if parsed_args.data_plane_status:
             attrs['data_plane_status'] = parsed_args.data_plane_status
 
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
+
         if attrs:
             with common.check_missing_extension_if_error(
                     self.app.client_manager.network, attrs):
@@ -898,7 +906,7 @@ class ShowPort(command.ShowOne):
 
 # TODO(abhiraut): Use the SDK resource mapped attribute names once the
 # OSC minimum requirements include SDK 1.0.
-class UnsetPort(command.Command):
+class UnsetPort(common.NeutronUnsetCommandWithExtraArgs):
     _description = _("Unset port properties")
 
     def get_parser(self, prog_name):
@@ -1019,6 +1027,9 @@ class UnsetPort(command.Command):
         if parsed_args.numa_policy:
             attrs['numa_affinity_policy'] = None
 
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
+
         if attrs:
             client.update_port(obj, **attrs)
 
